package TestWith;
use Mojo::Role;

sub test_method {
  return 1;
}

1;

